Class: Google::Apis::RecommenderV1beta1::GoogleCloudRecommenderV1beta1ListInsightTypesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/recommender_v1beta1/classes.rb,
lib/google/apis/recommender_v1beta1/representations.rb,
lib/google/apis/recommender_v1beta1/representations.rb

Overview

Response for the ListInsightTypes method. Next ID: 3

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRecommenderV1beta1ListInsightTypesResponse

Returns a new instance of GoogleCloudRecommenderV1beta1ListInsightTypesResponse.



435
436
437
# File 'lib/google/apis/recommender_v1beta1/classes.rb', line 435

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#insight_typesArray<Google::Apis::RecommenderV1beta1::GoogleCloudRecommenderV1beta1InsightType>

The set of recommenders available Corresponds to the JSON property insightTypes



427
428
429
# File 'lib/google/apis/recommender_v1beta1/classes.rb', line 427

def insight_types
  @insight_types
end

#next_page_tokenString

A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


433
434
435
# File 'lib/google/apis/recommender_v1beta1/classes.rb', line 433

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



440
441
442
443
# File 'lib/google/apis/recommender_v1beta1/classes.rb', line 440

def update!(**args)
  @insight_types = args[:insight_types] if args.key?(:insight_types)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end