Class: Google::Apis::RecommenderV1beta1::GoogleCloudRecommenderV1beta1ListInsightsResponse
- Inherits:
-
Object
- Object
- Google::Apis::RecommenderV1beta1::GoogleCloudRecommenderV1beta1ListInsightsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/recommender_v1beta1/classes.rb,
lib/google/apis/recommender_v1beta1/representations.rb,
lib/google/apis/recommender_v1beta1/representations.rb
Overview
Response to the ListInsights method.
Instance Attribute Summary collapse
-
#insights ⇒ Array<Google::Apis::RecommenderV1beta1::GoogleCloudRecommenderV1beta1Insight>
The set of insights for the
parentresource. -
#next_page_token ⇒ String
A token that can be used to request the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRecommenderV1beta1ListInsightsResponse
constructor
A new instance of GoogleCloudRecommenderV1beta1ListInsightsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRecommenderV1beta1ListInsightsResponse
Returns a new instance of GoogleCloudRecommenderV1beta1ListInsightsResponse.
467 468 469 |
# File 'lib/google/apis/recommender_v1beta1/classes.rb', line 467 def initialize(**args) update!(**args) end |
Instance Attribute Details
#insights ⇒ Array<Google::Apis::RecommenderV1beta1::GoogleCloudRecommenderV1beta1Insight>
The set of insights for the parent resource.
Corresponds to the JSON property insights
459 460 461 |
# File 'lib/google/apis/recommender_v1beta1/classes.rb', line 459 def insights @insights end |
#next_page_token ⇒ String
A token that can be used to request the next page of results. This field is
empty if there are no additional results.
Corresponds to the JSON property nextPageToken
465 466 467 |
# File 'lib/google/apis/recommender_v1beta1/classes.rb', line 465 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
472 473 474 475 |
# File 'lib/google/apis/recommender_v1beta1/classes.rb', line 472 def update!(**args) @insights = args[:insights] if args.key?(:insights) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |