Class: Google::Apis::RecommenderV1beta1::GoogleCloudRecommenderV1beta1ListRecommendationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::RecommenderV1beta1::GoogleCloudRecommenderV1beta1ListRecommendationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/recommender_v1beta1/classes.rb,
lib/google/apis/recommender_v1beta1/representations.rb,
lib/google/apis/recommender_v1beta1/representations.rb
Overview
Response to the ListRecommendations method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token that can be used to request the next page of results.
-
#recommendations ⇒ Array<Google::Apis::RecommenderV1beta1::GoogleCloudRecommenderV1beta1Recommendation>
The set of recommendations for the
parentresource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRecommenderV1beta1ListRecommendationsResponse
constructor
A new instance of GoogleCloudRecommenderV1beta1ListRecommendationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRecommenderV1beta1ListRecommendationsResponse
Returns a new instance of GoogleCloudRecommenderV1beta1ListRecommendationsResponse.
493 494 495 |
# File 'lib/google/apis/recommender_v1beta1/classes.rb', line 493 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token that can be used to request the next page of results. This field is
empty if there are no additional results.
Corresponds to the JSON property nextPageToken
486 487 488 |
# File 'lib/google/apis/recommender_v1beta1/classes.rb', line 486 def next_page_token @next_page_token end |
#recommendations ⇒ Array<Google::Apis::RecommenderV1beta1::GoogleCloudRecommenderV1beta1Recommendation>
The set of recommendations for the parent resource.
Corresponds to the JSON property recommendations
491 492 493 |
# File 'lib/google/apis/recommender_v1beta1/classes.rb', line 491 def recommendations @recommendations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
498 499 500 501 |
# File 'lib/google/apis/recommender_v1beta1/classes.rb', line 498 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @recommendations = args[:recommendations] if args.key?(:recommendations) end |