Class: Google::Apis::RecommenderV1beta1::GoogleCloudRecommenderV1beta1OperationGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/recommender_v1beta1/classes.rb,
lib/google/apis/recommender_v1beta1/representations.rb,
lib/google/apis/recommender_v1beta1/representations.rb

Overview

Group of operations that need to be performed atomically.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRecommenderV1beta1OperationGroup

Returns a new instance of GoogleCloudRecommenderV1beta1OperationGroup.



767
768
769
# File 'lib/google/apis/recommender_v1beta1/classes.rb', line 767

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::RecommenderV1beta1::GoogleCloudRecommenderV1beta1Operation>

List of operations across one or more resources that belong to this group. Loosely based on RFC6902 and should be performed in the order they appear. Corresponds to the JSON property operations



765
766
767
# File 'lib/google/apis/recommender_v1beta1/classes.rb', line 765

def operations
  @operations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



772
773
774
# File 'lib/google/apis/recommender_v1beta1/classes.rb', line 772

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
end