Class: Google::Apis::RecommenderV1beta1::GoogleTypeMoney
- Inherits:
-
Object
- Object
- Google::Apis::RecommenderV1beta1::GoogleTypeMoney
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/recommender_v1beta1/classes.rb,
lib/google/apis/recommender_v1beta1/representations.rb,
lib/google/apis/recommender_v1beta1/representations.rb
Overview
Represents an amount of money with its currency type.
Instance Attribute Summary collapse
-
#currency_code ⇒ String
The three-letter currency code defined in ISO 4217.
-
#nanos ⇒ Fixnum
Number of nano (10^-9) units of the amount.
-
#units ⇒ Fixnum
The whole units of the amount.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleTypeMoney
constructor
A new instance of GoogleTypeMoney.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleTypeMoney
Returns a new instance of GoogleTypeMoney.
1178 1179 1180 |
# File 'lib/google/apis/recommender_v1beta1/classes.rb', line 1178 def initialize(**args) update!(**args) end |
Instance Attribute Details
#currency_code ⇒ String
The three-letter currency code defined in ISO 4217.
Corresponds to the JSON property currencyCode
1161 1162 1163 |
# File 'lib/google/apis/recommender_v1beta1/classes.rb', line 1161 def currency_code @currency_code end |
#nanos ⇒ Fixnum
Number of nano (10^-9) units of the amount. The value must be between -999,999,
999 and +999,999,999 inclusive. If units is positive, nanos must be
positive or zero. If units is zero, nanos can be positive, zero, or
negative. If units is negative, nanos must be negative or zero. For
example $-1.75 is represented as units=-1 and nanos=-750,000,000.
Corresponds to the JSON property nanos
1170 1171 1172 |
# File 'lib/google/apis/recommender_v1beta1/classes.rb', line 1170 def nanos @nanos end |
#units ⇒ Fixnum
The whole units of the amount. For example if currencyCode is "USD", then
1 unit is one US dollar.
Corresponds to the JSON property units
1176 1177 1178 |
# File 'lib/google/apis/recommender_v1beta1/classes.rb', line 1176 def units @units end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1183 1184 1185 1186 1187 |
# File 'lib/google/apis/recommender_v1beta1/classes.rb', line 1183 def update!(**args) @currency_code = args[:currency_code] if args.key?(:currency_code) @nanos = args[:nanos] if args.key?(:nanos) @units = args[:units] if args.key?(:units) end |