Class: Google::Apis::RecommenderV1beta1::GoogleCloudRecommenderV1beta1InsightTypeConfig
- Inherits:
-
Object
- Object
- Google::Apis::RecommenderV1beta1::GoogleCloudRecommenderV1beta1InsightTypeConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/recommender_v1beta1/classes.rb,
lib/google/apis/recommender_v1beta1/representations.rb,
lib/google/apis/recommender_v1beta1/representations.rb
Overview
Configuration for an InsightType.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Allows clients to store small amounts of arbitrary data.
-
#display_name ⇒ String
A user-settable field to provide a human-readable name to be used in user interfaces.
-
#etag ⇒ String
Fingerprint of the InsightTypeConfig.
-
#insight_type_generation_config ⇒ Google::Apis::RecommenderV1beta1::GoogleCloudRecommenderV1beta1InsightTypeGenerationConfig
A configuration to customize the generation of insights.
-
#name ⇒ String
Identifier.
-
#revision_id ⇒ String
Output only.
-
#update_time ⇒ String
Last time when the config was updated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRecommenderV1beta1InsightTypeConfig
constructor
A new instance of GoogleCloudRecommenderV1beta1InsightTypeConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRecommenderV1beta1InsightTypeConfig
Returns a new instance of GoogleCloudRecommenderV1beta1InsightTypeConfig.
389 390 391 |
# File 'lib/google/apis/recommender_v1beta1/classes.rb', line 389 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Allows clients to store small amounts of arbitrary data. Annotations must
follow the Kubernetes syntax. The total size of all keys and values combined
is limited to 256k. Key can have 2 segments: prefix (optional) and name (
required), separated by a slash (/). Prefix must be a DNS subdomain. Name must
be 63 characters or less, begin and end with alphanumerics, with dashes (-),
underscores (_), dots (.), and alphanumerics between.
Corresponds to the JSON property annotations
351 352 353 |
# File 'lib/google/apis/recommender_v1beta1/classes.rb', line 351 def annotations @annotations end |
#display_name ⇒ String
A user-settable field to provide a human-readable name to be used in user
interfaces.
Corresponds to the JSON property displayName
357 358 359 |
# File 'lib/google/apis/recommender_v1beta1/classes.rb', line 357 def display_name @display_name end |
#etag ⇒ String
Fingerprint of the InsightTypeConfig. Provides optimistic locking when
updating.
Corresponds to the JSON property etag
363 364 365 |
# File 'lib/google/apis/recommender_v1beta1/classes.rb', line 363 def etag @etag end |
#insight_type_generation_config ⇒ Google::Apis::RecommenderV1beta1::GoogleCloudRecommenderV1beta1InsightTypeGenerationConfig
A configuration to customize the generation of insights. Eg, customizing the
lookback period considered when generating a insight.
Corresponds to the JSON property insightTypeGenerationConfig
369 370 371 |
# File 'lib/google/apis/recommender_v1beta1/classes.rb', line 369 def insight_type_generation_config @insight_type_generation_config end |
#name ⇒ String
Identifier. Name of insight type config. Eg, projects/[PROJECT_NUMBER]/
locations/[LOCATION]/insightTypes/[INSIGHT_TYPE_ID]/config
Corresponds to the JSON property name
375 376 377 |
# File 'lib/google/apis/recommender_v1beta1/classes.rb', line 375 def name @name end |
#revision_id ⇒ String
Output only. Immutable. The revision ID of the config. A new revision is
committed whenever the config is changed in any way. The format is an 8-
character hexadecimal string.
Corresponds to the JSON property revisionId
382 383 384 |
# File 'lib/google/apis/recommender_v1beta1/classes.rb', line 382 def revision_id @revision_id end |
#update_time ⇒ String
Last time when the config was updated.
Corresponds to the JSON property updateTime
387 388 389 |
# File 'lib/google/apis/recommender_v1beta1/classes.rb', line 387 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
394 395 396 397 398 399 400 401 402 |
# File 'lib/google/apis/recommender_v1beta1/classes.rb', line 394 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @insight_type_generation_config = args[:insight_type_generation_config] if args.key?(:insight_type_generation_config) @name = args[:name] if args.key?(:name) @revision_id = args[:revision_id] if args.key?(:revision_id) @update_time = args[:update_time] if args.key?(:update_time) end |